--AH:ScriptId=e7131449-a735-4a77-93b5-7026a6e3011c;2853
DROP TABLE [RetentionPolicies]
GO

CREATE TABLE [RetentionPolicies]
(
	[RetentionPolicy_Id] INT NOT NULL IDENTITY(1, 1),
	[RetentionPolicy_Name] NVARCHAR(50) NULL,
	[PurgeType_Code] CHAR(1) NOT NULL,

	[PurgeIn_Application_Id] INT NULL,
	[PurgeIn_ApplicationGroup_Id] INT NULL,
	[PurgeIn_OnlyDeployedReleases_Indicator] YNINDICATOR NOT NULL,
	[PurgeIn_OnlyRejectedBuilds_Indicator] YNINDICATOR NOT NULL,
	[PurgeIn_Workflow_Id] INT NULL,
	[PurgeIn_Environment_Id] INT NULL,
	[PurgeIn_BuildStep_Indicator] YNINDICATOR NOT NULL,

	[Retention_Count] INT NULL,
	[Retention_Size] BIGINT NULL,
	[Retention_Days_Count] INT NULL,
	
    [PurgeWindow_Start_Minutes] INT NULL,
    [PurgeWindow_Duration_Minutes] INT NULL,

	[PurgeNow_Indicator] YNINDICATOR NOT NULL,

	[CreatedBy_User_Name] USERNAME NOT NULL,
	[CreatedOn_Date] DATETIME NOT NULL,

	[ModifiedBy_User_Name] USERNAME NULL,
	[ModifiedOn_Date] DATETIME NULL,

    [Active_Indicator] YNINDICATOR NOT NULL,

	CONSTRAINT [PK__RetentionPolicies]
		PRIMARY KEY ([RetentionPolicy_Id]),

	CONSTRAINT [CK__RetentionPolicies__RetentionPolicy_Name]
		CHECK (RTRIM(LTRIM([RetentionPolicy_Name])) <> ''),

	CONSTRAINT [CK__RetentionPolicies__PurgeType_Code]
		CHECK ([PurgeType_Code] IN ('R', 'B', 'L', 'A')),

	CONSTRAINT [FK__RetentionPolicies__Applications]
		FOREIGN KEY ([PurgeIn_Application_Id])
		REFERENCES [Applications] ([Application_Id]),

	CONSTRAINT [FK__RetentionPolicies__ApplicationGroups]
		FOREIGN KEY ([PurgeIn_ApplicationGroup_Id])
		REFERENCES [ApplicationGroups] ([ApplicationGroup_Id]),

	CONSTRAINT [FK__RetentionPolicies__Workflows]
		FOREIGN KEY ([PurgeIn_Workflow_Id])
		REFERENCES [Workflows] ([Workflow_Id]),

	CONSTRAINT [FK__RetentionPolicies__Environments]
		FOREIGN KEY ([PurgeIn_Environment_Id])
		REFERENCES [Environments] ([Environment_Id]),

	CONSTRAINT [CK__RetentionPolicies__Retention_Count]
		CHECK ([Retention_Count] IS NULL OR [Retention_Count] >= 0),

	CONSTRAINT [CK__RetentionPolicies__Retention_Size]
		CHECK ([Retention_Size] IS NULL OR [Retention_Size] >= 0),

	CONSTRAINT [CK__RetentionPolicies__Retention_Days_Count]
		CHECK ([Retention_Days_Count] IS NULL OR [Retention_Days_Count] >= 0),

    CONSTRAINT [CK__RetentionPolicies__PurgeWindow_Valid]
        CHECK (
                ([PurgeWindow_Start_Minutes] IS NULL AND [PurgeWindow_Duration_Minutes] IS NULL) 
                OR ([PurgeWindow_Start_Minutes] >= 0 AND [PurgeWindow_Start_Minutes] < 1440 
                    AND [PurgeWindow_Duration_Minutes] > 0 AND [PurgeWindow_Duration_Minutes] <= 1440)
              ),

	CONSTRAINT [CK__RetentionPolicies__ApplicationScope_Valid]
		CHECK ([PurgeIn_Application_Id] IS NULL OR [PurgeIn_ApplicationGroup_Id] IS NULL),

	CONSTRAINT [CK__RetentionPolicies__SizeValidForScope]
		CHECK ([Retention_Size] IS NULL OR [PurgeType_Code] IN ('L', 'A')),

	CONSTRAINT [CK__RetentionPolicies__CountValidForScope]
		CHECK ([Retention_Count] IS NULL OR [PurgeType_Code] IN ('R', 'B', 'A')),

	CONSTRAINT [CK__RetentionPolicies__BuildStatusValidForScope]
		CHECK ([PurgeIn_OnlyRejectedBuilds_Indicator] = 'N' OR [PurgeType_Code] IN ('B', 'L', 'A')),

	CONSTRAINT [CK__RetentionPolicies__EnvironmentValidForScope]
		CHECK (([PurgeIn_Environment_Id] IS NULL AND [PurgeIn_BuildStep_Indicator] = 'N') OR [PurgeType_Code] = 'L'),

	CONSTRAINT [CK__RetentionPolicies__EnvironmentScope_Valid]
		CHECK ([PurgeIn_Environment_Id] IS NULL OR [PurgeIn_BuildStep_Indicator] = 'N')
)