IF OBJECT_ID('[ConfigurationFileVersions_Extended]') IS NOT NULL DROP VIEW [ConfigurationFileVersions_Extended]
GO

CREATE VIEW [ConfigurationFileVersions_Extended] AS

SELECT CFV.[ConfigurationFile_Id],
       CFV.[Instance_Name],
       CFV.[Version_Number],
	   CFI.[Environment_Id],
	   E.[Environment_Name],
	   CFI.[Active_Indicator],
	   D.[Deployable_Id],
	   D.[Deployable_Name],
	   CFI.[Template_Indicator],
	   CFI.[Template_Instance_Name],
	   CFI.[TransformType_Code],
	   CF.[FilePath_Text],
	   A.[Application_Id],
	   A.[Application_Name],
	   AG.[ApplicationGroup_Id],
	   AG.[ApplicationGroup_Name],
	   [VersionNotes_Text] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[VersionNotes_Text] ELSE CFV_Last.[VersionNotes_Text] END,
	   [File_Date] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[File_Date] ELSE CFV_Last.[File_Date] END,
	   [File_Bytes] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[File_Bytes] ELSE CFV_Last.[File_Bytes] END,
	   [CreatedBy_User_Name] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[CreatedBy_User_Name] ELSE CFV_Last.[CreatedBy_User_Name] END,
	   [CreatedOn_Date] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[CreatedOn_Date] ELSE CFV_Last.[CreatedOn_Date] END,
	   CFV.[Null_Indicator]

  FROM [ConfigurationFileVersions] CFV
       INNER JOIN [ConfigurationFiles] CF
	           ON CF.[ConfigurationFile_Id] = CFV.[ConfigurationFile_Id]
	   INNER JOIN [ConfigurationFileInstances] CFI
	           ON CFI.[ConfigurationFile_Id] = CFV.[ConfigurationFile_Id]
			  AND CFI.[Instance_Name] = CFV.[Instance_Name]
	    LEFT JOIN [Environments] E
	           ON E.[Environment_Id] = CFI.[Environment_Id]
	    LEFT JOIN [Deployables] D
	           ON D.[Deployable_Id] = CF.[Deployable_Id]
	   INNER JOIN [Applications] A
	           ON A.[Application_Id] = CF.[Application_Id]
	    LEFT JOIN [ApplicationGroups] AG
	           ON AG.[ApplicationGroup_Id] = A.[ApplicationGroup_Id]
	    LEFT JOIN (SELECT [ConfigurationFile_Id],
		                  [Instance_Name],
						  [Version_Number],
						  [Last_NonNull_Version] = (SELECT MAX(CFV_Inner_Inner.[Version_Number])
						                              FROM [ConfigurationFileVersions] CFV_Inner_Inner
													 WHERE CFV_Inner_Inner.[ConfigurationFile_Id] = CFV_Inner.[ConfigurationFile_Id]
													   AND CFV_Inner_Inner.[Instance_Name] = CFV_Inner.[Instance_Name]
													   AND CFV_Inner_Inner.[Version_Number] < CFV_Inner.[Version_Number]
													   AND CFV_Inner_Inner.[Null_Indicator] = 'N')
		             FROM [ConfigurationFileVersions] CFV_Inner
					WHERE [Null_Indicator] = 'Y') CFV2
			   ON CFV.[Null_Indicator] = 'Y'
			  AND CFV2.[ConfigurationFile_Id] = CFV.[ConfigurationFile_Id]
			  AND CFV2.[Instance_Name] = CFV.[Instance_Name]
			  AND CFV2.[Version_Number] = CFV.[Version_Number]
		LEFT JOIN [ConfigurationFileVersions] CFV_Last
		       ON CFV.[Null_Indicator] = 'Y'
			  AND CFV_Last.[ConfigurationFile_Id] = CFV.[ConfigurationFile_Id]
			  AND CFV_Last.[Instance_Name] = CFV.[Instance_Name]
			  AND CFV_Last.[Version_Number] = CFV2.[Last_NonNull_Version]
GO
