EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ChangeControls_PerformChangeControl',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Adds a change control performance for a specified environment.'
GO

IF OBJECT_ID('[ChangeControls_PerformChangeControl]') IS NOT NULL DROP PROCEDURE [ChangeControls_PerformChangeControl]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ChangeControls_PerformChangeControl]
(
	@ChangeControl_Id INT,
	@Environment_Id INT,
	@Notes_Text VARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON
    
BEGIN TRY
	BEGIN TRANSACTION
    
    DECLARE @Application_Id INT
    DECLARE @ChangeControlPerformance_Id INT
    
    SELECT @Application_Id = R.[Application_Id]
    FROM [ChangeControls] CC
		       INNER JOIN [Releases] R
		           ON R.[Release_Id] = CC.[Release_Id]
    WHERE [ChangeControl_Id] = @ChangeControl_Id
    
    INSERT INTO [ChangeControlPerformances]
    (
        [ChangeControl_Id]
       ,[Environment_Id]
       ,[PerformedBy_User_Name]
       ,[Performed_Date]
       ,[Notes_Text]
    )
    VALUES
    (
        @ChangeControl_Id,
        @Environment_Id,
        dbo.Session_GetUserName(),
        GETUTCDATE(),
        @Notes_Text
    )
    
    SET @ChangeControlPerformance_Id = SCOPE_IDENTITY()
    
    EXEC [Events_RaiseEvent] 'CCTPRF', @Application_Id, @ChangeControl_Id, @ChangeControlPerformance_Id
    
COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ChangeControls_PerformChangeControl] TO [BuildMasterUser_Role]
