EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ContainerSources_CreateOrUpdateContainerSource',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ContainerSource_Id',
    /* Description_Text        */ 'Creates a new container source or updates an existing one.'
GO

IF OBJECT_ID('[ContainerSources_CreateOrUpdateContainerSource]') IS NOT NULL DROP PROCEDURE [ContainerSources_CreateOrUpdateContainerSource]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ContainerSources_CreateOrUpdateContainerSource]
(
	@Registry_Url NVARCHAR(255),
    @ContainerSource_Name NVARCHAR(50),
    @Credential_Name NVARCHAR(50),
    @ContainerSource_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @ContainerSource_Id IS NULL
	BEGIN
		INSERT INTO [ContainerSources] 
		(
            [Registry_Url],
            [ContainerSource_Name],
            [Credential_Name]
		)
		VALUES
		(
			@Registry_Url,
            @ContainerSource_Name,
            @Credential_Name
		)

		SET @ContainerSource_Id = SCOPE_IDENTITY()
	END
	ELSE
		UPDATE [ContainerSources]
		   SET [Registry_Url] = @Registry_Url,
               [ContainerSource_Name] = @ContainerSource_Name,
               [Credential_Name] = @Credential_Name
         WHERE [ContainerSource_Id] = @ContainerSource_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ContainerSources_CreateOrUpdateContainerSource] TO [BuildMasterUser_Role]
