EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Notifiers_CreateOrUpdateNotifier',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new notifier, or updates an existing one'
GO

IF OBJECT_ID('[Notifiers_CreateOrUpdateNotifier]') IS NOT NULL
	DROP PROCEDURE [Notifiers_CreateOrUpdateNotifier]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Notifiers_CreateOrUpdateNotifier]
(
	@Notifier_Id INT = NULL,
	@Notifier_Name VARCHAR(50),
	@Notifier_Description VARCHAR(MAX),
	@Notifier_Configuration VARCHAR(MAX),
	@Owner_User_Name USERNAME,
	@Active_Indicator YNINDICATOR,
	@EventCodeList_Csv VARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Notifier_Id IS NULL BEGIN
		INSERT INTO [Notifiers]
				   ([Notifier_Name]
				   ,[Notifier_Description]
				   ,[Notifier_Configuration]
				   ,[Owner_User_Name]
				   ,[Active_Indicator])
			 VALUES
				   (@Notifier_Name
				   ,@Notifier_Description
				   ,@Notifier_Configuration
				   ,@Owner_User_Name
				   ,@Active_Indicator)
		SET @Notifier_Id = SCOPE_IDENTITY()
	END ELSE BEGIN
		UPDATE [Notifiers] SET
		   [Notifier_Name]=@Notifier_Name
		   ,[Notifier_Description] = @Notifier_Description
		   ,[Notifier_Configuration] = @Notifier_Configuration
		   ,[Active_Indicator] = @Active_Indicator
		WHERE [Notifier_Id] = @Notifier_Id
		IF @@ROWCOUNT=0 RAISERROR('Notifier #%i does not exist.',16,1,@Notifier_Id)

		DELETE [NotifierEventCodes] 
		 WHERE [Notifier_Id] = @Notifier_Id
	END

	INSERT INTO [NotifierEventCodes] ([Notifier_Id],[Event_Code])
	SELECT @Notifier_Id, V.[Value_Text]
	  FROM dbo.CsvToTable(@EventCodeList_Csv,',') V

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Notifiers_CreateOrUpdateNotifier] TO [BuildMasterUser_Role]